(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[     47715,       1455]
NotebookOptionsPosition[     43607,       1326]
NotebookOutlinePosition[     44120,       1348]
CellTagsIndexPosition[     44034,       1343]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["ColorbarPlot Examples", "Section",
 CellChangeTimes->{{3.40045681375132*^9, 3.4004568168357553`*^9}, {
  3.400460892195835*^9, 3.4004608941887007`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"<<", "ColorbarPlot`"}], "\[IndentingNewLine]", 
 RowBox[{"?", "ColorbarPlot"}]}], "Input"],

Cell[BoxData[
 StyleBox["\<\"ColorbarPlot[ F[#1,#2] & , {Xmin, Xmax} , {Ymin, Ymax} , \
<options> ]:\\n  Creates a DensityPlot or a ContourPlot or a 3DPlot of the\\n \
 function F with an attached colorbar to denote its range.\\n\\nColorbarPlot[ \
{{x1, y1, \[Ellipsis]}, {x2, y2, \[Ellipsis]}, \[Ellipsis]} , <options> ]:\\n \
 Creates the List-based versions of the plots above.\\n  (E.g., \
ListContourPlot, ListPlot3D, etc.)\\n\\nThis is a list of options that \
ColorbarPlot accepts and their\\ndefault options. Where multiple options are \
listed, the first \\nis the default:\\n\\nGeneral:\\n  PlotType \[Rule] \
\\\"Density\\\" | \\\"Contour\\\" | \\\"3D\\\" | \\\"Point3D\\\"\\n  \
ColorFunction \[Rule] \\\"LakeColors\\\" | etc. \[Ellipsis] \\n  PlotRange \
\[Rule] Automatic | {min, max} | {{xmin, xmax}, {ymin, ymax}} |\\n    {{xmin \
,xmax}, {ymin, ymax}, {zmin, zmax}}\\n\\nFor the plot:\\n  XLabel \[Rule] \
\\\"\\\"\\n  YLabel \[Rule] \\\"\\\"\\n  ZLabel \[Rule] \\\"\\\"\\n  Title \
\[Rule] \\\"\\\"\\n  Height \[Rule] 8*72/2.54  (=8cm)\\n\\nFor the \
colorbar:\\n  CLabel \[Rule] \\\"\\\"\\n  CTicks \[Rule] All\\n  CTickSide \
\[Rule] Left | Right\\n  CSide \[Rule] Right | Left\\n  CTicksStyle->{}\\n  \
CLabelStyle->{}\\n  ColorbarOpts \[Rule] {}\\n\\n\\nUnknown options to \
ColorbarPlot are passed transparently\\nto the underlying plot function. Note \
that such options\\nare -not- passed to the colorbar; use the ColorbarOpts \
\\noption for this purpose instead.\\n\\nThe x- and y-ranges of the PlotRange \
option are passed directly\\nto the underlying plot function. The z-range \
handling is not as\\nintelligent as the one of the built-in plot functions. \
If set to\\n'Automatic' it will always cover the full range of the \
supplied\\ndata, regardless of the subset chosen with the x- and \
y-range.\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.487479347910805*^9},
 CellTags->"Info3487486547-3854386"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Overview", "Subsection",
 CellChangeTimes->{{3.4022647565623245`*^9, 3.4022647579643407`*^9}}],

Cell[TextData[{
 "Here is a quick summary of the types of plots the ",
 StyleBox["ColorbarPlot", "Input"],
 " package can generate.\nHere are the function-based plots with 2D inputs:"
}], "Text"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ColorbarPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"#1", "^", "2"}], "+", 
       RowBox[{"#2", "^", "2"}]}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotType", "\[Rule]", "pt"}], ",", "\[IndentingNewLine]", 
     RowBox[{"CSide", "\[Rule]", "cs"}], ",", "\[IndentingNewLine]", 
     RowBox[{"CTickSide", "\[Rule]", "ct"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ColorFunction", "\[Rule]", "col"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", "cr"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pt", ",", "\"\<Density\>\"", ",", "\"\<PlotType\>\""}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"\"\<Contour\>\"", ",", "\"\<Density\>\"", ",", "\"\<3D\>\""}], 
      "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"cs", ",", "Right", ",", "\"\<Bar location\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Left", ",", "Right"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ct", ",", "Left", ",", "\"\<Bar Ticks\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Left", ",", "Right"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"cr", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "120"}], "}"}], ",", "\"\<Plot range\>\""}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "50"}], ",", "120"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "150"}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "col", ",", "\"\<LakeColors\>\"", ",", "\"\<ColorFunction\>\""}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<DarkBands\>\"", ",", "\"\<LakeColors\>\"", ",", "\"\<Pastel\>\"", 
       ",", "\"\<Rainbow\>\"", ",", "\"\<SolarColors\>\"", ",", 
       "\"\<StarryNightColors\>\"", ",", "\"\<TemperatureMap\>\""}], "}"}]}], 
    "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ControlPlacement", "\[Rule]", "Left"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"],

Cell["Here are the list-based plots with 2D inputs:", "Text"],

Cell[BoxData[{
 RowBox[{"datafn", ":=", 
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"#1", "/", "5"}], " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"#2", "/", "5"}], ")"}], "^", "2"}]}], "]"}], 
   "&"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"data2", "=", 
   RowBox[{"Join", "@@", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", 
        RowBox[{"datafn", "[", 
         RowBox[{"x", ",", "y"}], "]"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", 
        RowBox[{"-", "10"}], ",", "10"}], "}"}]}], "]"}]}]}], ";"}]}], "Input"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ColorbarPlot", "[", 
    RowBox[{"data2", ",", "\[IndentingNewLine]", 
     RowBox[{"PlotType", "\[Rule]", "pt"}], ",", 
     RowBox[{"CSide", "\[Rule]", "cs"}], ",", "\[IndentingNewLine]", 
     RowBox[{"CTickSide", "\[Rule]", "ct"}], ",", 
     RowBox[{"ColorFunction", "\[Rule]", "col"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotRange", "\[Rule]", "cr"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"pt", ",", "\"\<Density\>\"", ",", "\"\<PlotType\>\""}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<Contour\>\"", ",", "\"\<Density\>\"", ",", "\"\<3D\>\"", ",", 
       "\"\<Point3D\>\""}], "}"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"cs", ",", "Right", ",", "\"\<Bar location\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Left", ",", "Right"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ct", ",", "Left", ",", "\"\<Bar Ticks\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Left", ",", "Right"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"cr", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", "\"\<Plot range\>\""}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "5"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "col", ",", "\"\<LakeColors\>\"", ",", "\"\<ColorFunction\>\""}], "}"}],
      ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<DarkBands\>\"", ",", "\"\<LakeColors\>\"", ",", "\"\<Pastel\>\"", 
       ",", "\"\<Rainbow\>\"", ",", "\"\<SolarColors\>\"", ",", 
       "\"\<StarryNightColors\>\"", ",", "\"\<TemperatureMap\>\""}], "}"}]}], 
    "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ControlPlacement", "\[Rule]", "Left"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Defaults", "Subsection",
 CellChangeTimes->{{3.400456831166362*^9, 3.4004568318673697`*^9}, 
   3.400460905625146*^9}],

Cell[BoxData[
 RowBox[{"ColorbarPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"#1", "^", "2"}], "+", 
     RowBox[{"#2", "^", "2"}]}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "]"}]], "Input"],

Cell["\<\
Inline functions don't have to be used; any function that takes two arguments \
is allowed. Axis plot ranges may be prefixed by a meaningless label \
(meaningless with respect to syntax, that is):\
\>", "Text",
 CellChangeTimes->{{3.4004621347124863`*^9, 3.400462163143368*^9}, {
  3.4016846755459633`*^9, 3.401684724566451*^9}}],

Cell[BoxData[{
 RowBox[{"f", ":=", 
  RowBox[{
   RowBox[{"Sin", "[", 
    RowBox[{
     RowBox[{"#1", "^", "2"}], "+", 
     RowBox[{"#2", "^", "2"}]}], "]"}], "&"}]}], "\[IndentingNewLine]", 
 RowBox[{"ColorbarPlot", "[", 
  RowBox[{"f", ",", 
   RowBox[{"{", 
    RowBox[{"a", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"b", ",", 
     RowBox[{"-", "5"}], ",", "5"}], "}"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4004534981937823`*^9, 3.400453522939365*^9}, {
   3.400453588243267*^9, 3.4004535996696978`*^9}, {3.4004536323667135`*^9, 
   3.4004536453854337`*^9}, {3.4004537591289887`*^9, 
   3.4004538013396845`*^9}, {3.4004538466548448`*^9, 3.400453866713688*^9}, {
   3.400454715514203*^9, 3.400454721042152*^9}, {3.400454768510408*^9, 
   3.400454833834339*^9}, {3.4004548707474174`*^9, 3.4004548775872526`*^9}, {
   3.4004549204689136`*^9, 3.400455042474349*^9}, {3.400455087659322*^9, 
   3.400455115098778*^9}, {3.4004551616356945`*^9, 3.4004551631879263`*^9}, {
   3.4004552172056*^9, 3.4004552731760817`*^9}, {3.4004553222466416`*^9, 
   3.4004553303482914`*^9}, 3.4004553846063104`*^9, {3.400456065505395*^9, 
   3.400456094987789*^9}, {3.400456791929942*^9, 3.400456792240389*^9}, {
   3.4004621648758593`*^9, 3.400462264138592*^9}, {3.401683662208856*^9, 
   3.4016836692289505`*^9}}],

Cell["List-like plots are automatically recognised:", "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"data2d", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Sin", "[", 
      RowBox[{"x", " ", 
       RowBox[{"y", "^", "2"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ColorbarPlot", "[", "data2d", "]"}]}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Basic options", "Subsection",
 CellChangeTimes->{{3.4004568356728415`*^9, 3.400456840820243*^9}}],

Cell["Labels and things:", "Text"],

Cell[BoxData[
 RowBox[{"ColorbarPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"#1", "^", "2"}], "+", 
     RowBox[{"#2", "^", "2"}]}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotType", "\[Rule]", "\"\<Contour\>\""}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ColorFunction", "\[Rule]", "\"\<DarkBands\>\""}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"XLabel", "\[Rule]", "\"\<x\>\""}], ",", "\[IndentingNewLine]", 
   RowBox[{"YLabel", "\[Rule]", "\"\<y\>\""}], ",", "\[IndentingNewLine]", 
   RowBox[{"Title", "\[Rule]", "\"\<Title\>\""}], ",", "\[IndentingNewLine]", 
   RowBox[{"CLabel", "\[Rule]", "\"\<Range\>\""}], ",", "\[IndentingNewLine]", 
   RowBox[{"Height", "\[Rule]", "300"}]}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot range", "Subsection"],

Cell["\<\
Plots that are to be directly compared should be plotted with the same \
colorbars. To do this we explicitly choose the plot range:\
\>", "Text"],

Cell[BoxData[{
 RowBox[{"f1", ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{"#1", "^", "2"}], "+", 
      RowBox[{"#2", "^", "2"}]}], "]"}], "-", "1"}], 
   "&"}]}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ColorbarPlot", "[", 
    RowBox[{"f1", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ColorbarPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"0.5", 
       RowBox[{"f1", "[", 
        RowBox[{"#1", ",", "#2"}], "]"}]}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "0.4"}], "}"}]}]}], "]"}]}], "}"}]}], "Input"],

Cell["\<\
Note that if the plot range is smaller than the bounds of the plot, the plot \
will be truncated:\
\>", "Text"],

Cell[BoxData[{
 RowBox[{"f1", ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"Sqrt", "[", 
     RowBox[{
      RowBox[{"#1", "^", "2"}], "+", 
      RowBox[{"#2", "^", "2"}]}], "]"}], "-", "1"}], 
   "&"}]}], "\[IndentingNewLine]", 
 RowBox[{"f2", ":=", 
  RowBox[{
   RowBox[{"0.5", 
    RowBox[{"f1", "[", 
     RowBox[{"#1", ",", "#2"}], "]"}]}], "&"}]}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ColorbarPlot", "[", 
    RowBox[{"f1", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ColorbarPlot", "[", 
    RowBox[{"f2", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.2"}], ",", "0.1"}], "}"}]}]}], "]"}]}], 
  "}"}]}], "Input"],

Cell[TextData[{
 StyleBox["PlotRange", "Input"],
 " takes options in the following forms: (",
 StyleBox["Automatic", "Input"],
 " can also be used instead of ",
 StyleBox["Full", "Input"],
 ")"
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"ColorbarPlot", ",", 
    RowBox[{"PlotType", "\[Rule]", "\"\<Contour\>\""}], ",", 
    RowBox[{"ColorFunction", "\[Rule]", "\"\<Rainbow\>\""}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ColorbarPlot", "[", 
    RowBox[{"f1", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "Full"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ColorbarPlot", "[", 
    RowBox[{"f1", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1.5"}], ",", "Full"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ColorbarPlot", "[", 
    RowBox[{"f1", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Full", ",", "0.8"}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ColorbarPlot", "[", 
    RowBox[{"f1", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1.5"}], ",", "0.8"}], "}"}]}]}], "]"}]}], 
  "}"}]}], "Input"],

Cell[TextData[{
 StyleBox["PlotRange", "Input"],
 " can be specified for the x- and y-range of the plot:"
}], "Text",
 CellChangeTimes->{{3.487419847277476*^9, 3.487419863317403*^9}, 
   3.487419974770751*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Sqrt", "[", 
         RowBox[{
          RowBox[{"x", "^", "2"}], "+", 
          RowBox[{"y", "^", "2"}]}], "]"}], "<", "1"}], ",", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "-", 
         RowBox[{"Sqrt", "[", 
          RowBox[{
           RowBox[{"x", "^", "2"}], "+", 
           RowBox[{"y", "^", "2"}]}], "]"}]}], "]"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", 
       RowBox[{"-", "1"}], ",", "1", ",", "0.125"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"y", ",", 
       RowBox[{"-", "1"}], ",", "1", ",", "0.125"}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.487419872891318*^9, 3.487419873316559*^9}}],

Cell[BoxData[
 RowBox[{"ColorbarPlot", "[", 
  RowBox[{"data", ",", 
   RowBox[{"InterpolationOrder", "\[Rule]", "0"}], ",", 
   RowBox[{"DataRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "2"}], "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.487419896384309*^9, 3.487419907206314*^9}}],

Cell["All ranges can be specified simultaneously :", "Text",
 CellChangeTimes->{{3.487419847277476*^9, 3.487419863317403*^9}, {
  3.487419927009278*^9, 3.487419976696268*^9}}],

Cell[BoxData[
 RowBox[{"ColorbarPlot", "[", 
  RowBox[{"data", ",", 
   RowBox[{"InterpolationOrder", "\[Rule]", "0"}], ",", 
   RowBox[{"DataRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "1"}], ",", "1"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "2"}], ",", "2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1.5"}], "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.487419985043014*^9, 3.487419987880862*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Customisation options", "Subsection",
 CellChangeTimes->{{3.4016888619557247`*^9, 3.401688865610981*^9}}],

Cell[TextData[{
 "Ticks on the colorbar are specified with ",
 StyleBox["CTicks", "Input"],
 ":"
}], "Text"],

Cell[BoxData[
 RowBox[{"ColorbarPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{"#1", " ", "#2"}], "]"}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"CTicks", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.25"}], ",", "0", ",", "0.75"}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"CSide", "\[Rule]", "Left"}], ",", "\[IndentingNewLine]", 
   RowBox[{"CTickSide", "\[Rule]", "Right"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4016888962650595`*^9, 3.4016889341295056`*^9}, {
  3.401689350788632*^9, 3.4016893586098785`*^9}, {3.4016893950122223`*^9, 
  3.401689529725931*^9}, {3.401689596572051*^9, 3.4016896524824467`*^9}}],

Cell[TextData[{
 "Ticks follow contours if explicit contours are specified with the ",
 StyleBox["Contours", "Input"],
 " option:"
}], "Text"],

Cell[BoxData[
 RowBox[{"ColorbarPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{"#1", " ", "#2"}], "]"}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotType", "\[Rule]", "\"\<Contour\>\""}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Contours", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.25"}], ",", "0", ",", "0.75"}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"CSide", "\[Rule]", "Left"}], ",", "\[IndentingNewLine]", 
   RowBox[{"CTickSide", "\[Rule]", "Right"}]}], "]"}]], "Input"],

Cell[TextData[{
 "This also works with the ",
 StyleBox["Plot", "Input"],
 StyleBox["Range", "Input"],
 " option:"
}], "Text"],

Cell[BoxData[
 RowBox[{"ColorbarPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{"#1", " ", "#2"}], "]"}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotType", "\[Rule]", "\"\<Contour\>\""}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Contours", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.25"}], ",", "0", ",", "0.75"}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "0.3"}], ",", "0.8"}], "}"}]}]}], "]"}]], "Input"],

Cell[TextData[{
 "You can change the style of the colorbar ticks using the ",
 StyleBox["CTicksStyle ", "Input"],
 "option:"
}], "Text",
 CellChangeTimes->{{3.464424316765661*^9, 3.46442441236893*^9}}],

Cell[BoxData[
 RowBox[{"ColorbarPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{"#1", " ", "#2"}], "]"}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotType", "\[Rule]", "\"\<Contour\>\""}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"CTicksStyle", "\[Rule]", "Bold"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.464424446461749*^9, 3.464424463244908*^9}}],

Cell[TextData[{
 "The style of the colorbar label is controlled by the ",
 StyleBox["CLabelStyle ", "Input"],
 "option:"
}], "Text",
 CellChangeTimes->{{3.464424316765661*^9, 3.46442441236893*^9}, {
  3.464424499073965*^9, 3.464424526695696*^9}}],

Cell[BoxData[
 RowBox[{"ColorbarPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{"#1", " ", "#2"}], "]"}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotType", "\[Rule]", "\"\<Contour\>\""}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"CLabel", "\[Rule]", "\"\<Hello\>\""}], ",", "\[IndentingNewLine]", 
   RowBox[{"CLabelStyle", "\[Rule]", 
    RowBox[{"FontSize", "\[Rule]", "20"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.464424536857383*^9, 3.464424553789928*^9}, {
  3.464424611526737*^9, 3.464424758361296*^9}, {3.464425154139994*^9, 
  3.464425157398935*^9}}],

Cell[TextData[{
 "Combine multiple style elements together with ",
 StyleBox["Directive ", "Input"]
}], "Text",
 CellChangeTimes->{{3.464424316765661*^9, 3.46442441236893*^9}, {
  3.464424499073965*^9, 3.464424526695696*^9}, {3.464425184801787*^9, 
  3.46442523653036*^9}, {3.464428213233888*^9, 3.464428216728619*^9}}],

Cell[BoxData[
 RowBox[{"ColorbarPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Sin", "[", 
     RowBox[{"#1", " ", "#2"}], "]"}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotType", "\[Rule]", "\"\<Contour\>\""}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"CLabel", "\[Rule]", "\"\<Hello\>\""}], ",", "\[IndentingNewLine]", 
   RowBox[{"CLabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Red", ",", "Italic", ",", "Bold", ",", 
      RowBox[{"FontSize", "\[Rule]", "20"}]}], "]"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"CTicksStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{"Green", ",", 
      RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.464425241054441*^9, 3.464425274541934*^9}, {
  3.464425315010121*^9, 3.464425326070002*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Passing options through to the plot", "Subsection"],

Cell[TextData[{
 "Options unknown to ",
 StyleBox["ColorbarPlot", "Input"],
 " are passed directly to ",
 StyleBox["the underlying plot function",
  FontWeight->"Plain"],
 ":"
}], "Text"],

Cell[BoxData[
 RowBox[{"ColorbarPlot", "[", 
  RowBox[{"f", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"ColorFunction", "\[Rule]", "\"\<Rainbow\>\""}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\"\<a\>\"", ",", "\"\<b\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\"\<c\>\"", ",", "\"\<d\>\""}], "}"}]}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"MaxRecursion", "\[Rule]", "1"}], ",", 
   RowBox[{"PlotPoints", "\[Rule]", "4"}]}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Passing options to the colorbar", "Subsection",
 CellChangeTimes->{{3.401682977123752*^9, 3.4016829855358477`*^9}}],

Cell[TextData[{
 "Most of the options passed to the main plot will not want to be passed onto \
the colorbar itself (which is a plot in its own right). Some are passed \
automatically (colour, height, contour ticks). Anything else needs to be \
passed explicitly with the ",
 StyleBox["ColorbarOpts", "Input"],
 " option:"
}], "Text"],

Cell[BoxData[
 RowBox[{"ColorbarPlot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Exp", "[", 
     RowBox[{"#1", " ", "#2"}], "]"}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"PlotType", "\[Rule]", "\"\<Contour\>\""}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"AspectRatio", "\[Rule]", "0.8"}], ",", "\[IndentingNewLine]", 
   RowBox[{"ColorbarOpts", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"AspectRatio", "\[Rule]", "5"}], "}"}]}]}], "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\[OpenCurlyQuote]Padding\[CloseCurlyQuote] the colorbar", "Subsection"],

Cell["\<\
If the title of the main plot uses lots of space, then you'll want to add \
padding to the colorbar:\
\>", "Text"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"ColorbarPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"#1", "+", 
        RowBox[{"#2", "^", "2"}]}], "]"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "3"}], "}"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<Large title\>\"", ",", 
        RowBox[{"FontSize", "\[Rule]", "28"}]}], "]"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"ColorbarPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Sin", "[", 
       RowBox[{"#1", "+", 
        RowBox[{"#2", "^", "2"}]}], "]"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "3"}], "}"}], ",", 
     RowBox[{"PlotLabel", "\[Rule]", 
      RowBox[{"Style", "[", 
       RowBox[{"\"\<Large title\>\"", ",", 
        RowBox[{"FontSize", "\[Rule]", "28"}]}], "]"}]}], ",", 
     RowBox[{"CPadding", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"30", ",", "40"}], "}"}]}]}], "]"}]}], "}"}]], "Input"],

Cell[TextData[{
 "Unfortunately, this feature is only half-baked. (More due a limitation of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "'s ",
 StyleBox["ImagePadding", "Input"],
 " than laziness on our part.) This technique spoils the vertical alignment \
of the colorbar and it only works if the colorbar ticks are on the inside:"
}], "Text"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ColorbarPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"#1", "^", "2"}], "+", 
       RowBox[{"#2", "^", "2"}]}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotType", "\[Rule]", "\"\<Contour\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"CPadding", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"hp", ",", "vp"}], "}"}]}], ",", "\[IndentingNewLine]", 
     RowBox[{"CSide", "\[Rule]", "cs"}], ",", "\[IndentingNewLine]", 
     RowBox[{"CTickSide", "\[Rule]", "ct"}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"cs", ",", "Left", ",", "\"\<Bar location\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Left", ",", "Right"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"ct", ",", "Left", ",", "\"\<Bar Ticks\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Left", ",", "Right"}], "}"}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"hp", ",", "30", ",", "\"\<horiz\>\""}], "}"}], ",", "0", ",", 
     "100", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"vp", ",", "20", ",", "\"\<vert\>\""}], "}"}], ",", "0", ",", 
     "100", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input"],

Cell[TextData[{
 "You can fine-tune things by specifying the ",
 StyleBox["ImagePadding", "Input"],
 " of the colorbar manually:"
}], "Text"],

Cell[BoxData[
 RowBox[{"Manipulate", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"ColorbarPlot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"#1", "^", "2"}], "+", 
       RowBox[{"#2", "^", "2"}]}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "10"}], ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "5"}], ",", "5"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"PlotType", "\[Rule]", "\"\<Contour\>\""}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"CSide", "\[Rule]", "Left"}], ",", "\[IndentingNewLine]", 
     RowBox[{"ColorbarOpts", "->", 
      RowBox[{"{", 
       RowBox[{"ImagePadding", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"l", ",", "r"}], "}"}], ",", 
          RowBox[{"{", 
           RowBox[{"u", ",", "d"}], "}"}]}], "}"}]}], "}"}]}]}], "]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"l", ",", "20", ",", "\"\<left\>\""}], "}"}], ",", "0", ",", 
     "40", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"r", ",", "0", ",", "\"\<right\>\""}], "}"}], ",", "0", ",", 
     "40", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"u", ",", "30", ",", "\"\<up\>\""}], "}"}], ",", "0", ",", "60",
      ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"d", ",", "20", ",", "\"\<down\>\""}], "}"}], ",", "0", ",", 
     "40", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Labeled\>\""}]}], "}"}]}], 
  "\[IndentingNewLine]", "]"}]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Caveat with RegionFunction", "Subsection"],

Cell["\<\
There are some problems with typical plot options that ColorbarPlot doesn't \
(yet) try to fix. I'd like to roll the workarounds shown below into the \
package so that the options work transparently, but that won't happen today.\
\>", "Text",
 CellChangeTimes->{{3.400975169624221*^9, 3.400975219816394*^9}}],

Cell[TextData[{
 "First of all, the ",
 StyleBox["RegionFunction", "Input"],
 " option doesn't take the colorbar into account: \n(note how the colorbar \
extends outside the range of colors shown in the plot)"
}], "Text",
 CellChangeTimes->{{3.400462358994989*^9, 3.400462388617584*^9}, {
  3.4004630425278606`*^9, 3.4004630593520527`*^9}, {3.400974747216829*^9, 
  3.400974753676117*^9}, {3.40097523339592*^9, 3.4009752338665967`*^9}, {
  3.4014891461652946`*^9, 3.401489187434637*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", 
   RowBox[{"ColorbarPlot", ",", 
    RowBox[{"PlotType", "\[Rule]", "\"\<Contour\>\""}]}], "]"}], 
  ";"}]], "Input"],

Cell[BoxData[{
 RowBox[{"fn", ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"#1", "^", "2"}], "-", 
    RowBox[{"#2", "^", "2"}]}], "&"}]}], "\[IndentingNewLine]", 
 RowBox[{"region", ":=", 
  RowBox[{
   RowBox[{
    RowBox[{"#1", "^", "2"}], "+", 
    RowBox[{"#2", "^", "2"}]}], "&"}]}], "\[IndentingNewLine]", 
 RowBox[{"ColorbarPlot", "[", 
  RowBox[{"f", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"RegionFunction", "\[Rule]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"1", "<", 
        RowBox[{"region", "[", 
         RowBox[{"#1", ",", "#2"}], "]"}]}], "&"}], "<", "6"}], ")"}]}]}], 
  "]"}]}], "Input"],

Cell[TextData[{
 "This problem can be solved by explicitly including the ",
 StyleBox["RegionFunction", "Input"],
 " with the function that is being contoured."
}], "Text",
 CellChangeTimes->{{3.400974609679059*^9, 3.4009746171498013`*^9}, {
  3.4014893267249265`*^9, 3.401489361114376*^9}}],

Cell[BoxData[
 RowBox[{"ColorbarPlot", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", "<", 
        RowBox[{"region", "[", 
         RowBox[{"#1", ",", "#2"}], "]"}], "<", "6"}], ")"}], ",", 
      "\[IndentingNewLine]", 
      RowBox[{"fn", "[", 
       RowBox[{"#1", ",", "#2"}], "]"}], ",", 
      RowBox[{"{", "}"}]}], "]"}], "&"}], "\[IndentingNewLine]", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "3"}], ",", "3"}], "}"}]}], "]"}]], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Miscellaneous ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " musings"
}], "Section",
 CellChangeTimes->{{3.4014904168724813`*^9, 3.4014904413877325`*^9}}],

Cell[CellGroupData[{

Cell["How to arrange two graphs inside a graphic", "Subsection",
 CellChangeTimes->{
  3.4014884737684355`*^9, {3.4014887255404654`*^9, 3.4014887529498787`*^9}}],

Cell[TextData[{
 StyleBox["GraphicsRow", "Input"],
 " is only suitable if the graphs are similarly sized. For our case, the \
colorbar is much smaller (horizontally) than the main graph. ",
 StyleBox["Row", "Input"],
 " produces what we want, but the result isn't a ",
 StyleBox["Graphic", "Input"],
 ", and hence can't be included in things like ",
 StyleBox["MathPSfrag", "Input"],
 ". The trick is to use ",
 StyleBox["Inset", "Input"],
 " to place the ",
 StyleBox["Row", "Input"],
 " output inside a ",
 StyleBox["Graphic", "Input"],
 " and then size it accordingly."
}], "Text",
 CellChangeTimes->{{3.4014887590887055`*^9, 3.4014888732128077`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"g1", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Sin", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Automatic", ",", "150"}], "}"}]}]}], "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"g2", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"Cos", "[", "x", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "0", ",", 
       RowBox[{"2", " ", "\[Pi]"}]}], "}"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Automatic", ",", "150"}], "}"}]}], ",", 
     RowBox[{"AspectRatio", "\[Rule]", "5"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Graphics", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"Inset", "[", 
     RowBox[{
      RowBox[{"Row", "[", 
       RowBox[{"{", 
        RowBox[{"g1", ",", "g2"}], "}"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0"}], "}"}]}], "]"}], "}"}], ",", 
   RowBox[{"ImageSize", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Automatic", ",", "150"}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.401488476762741*^9, 3.4014885367089396`*^9}, {
  3.4014885809325294`*^9, 3.4014886039456205`*^9}, {3.401488669249523*^9, 
  3.401488723217125*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["How to parse and pass options between multiple functions", "Subsection",
 CellChangeTimes->{{3.401489448159541*^9, 3.4014894549292755`*^9}, {
  3.4014904517025647`*^9, 3.401490467455216*^9}}],

Cell["\<\
First define a function that will be used to pass options to:\
\>", "Text",
 CellChangeTimes->{{3.4014910185676765`*^9, 3.401491028231573*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "g", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"b", "\[Rule]", "b0"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", 
   RowBox[{"OptionsPattern", "[", "]"}], "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{"g", ":", 
    RowBox[{"OptionValue", "[", "b", "]"}]}], "}"}]}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{
   RowBox[{"g", "[", "]"}], ",", 
   RowBox[{"g", "[", 
    RowBox[{"b", "\[Rule]", "bbb"}], "]"}]}], "}"}]}], "Input",
 CellChangeTimes->{{3.4014909540448976`*^9, 3.401491084242112*^9}, {
  3.401491240717112*^9, 3.401491241037573*^9}}],

Cell[TextData[{
 "Now we want a wrapper function that takes its own options and passes those \
applicable to the function ",
 StyleBox["g", "Code"],
 ". The naive way of filtering the options produces warning messages that we \
certainly don't want:"
}], "Text",
 CellChangeTimes->{{3.401491098783021*^9, 3.401491182142886*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "h", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"c", "\[Rule]", "c0"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"h", "[", 
   RowBox[{"opts", ":", 
    RowBox[{"OptionsPattern", "[", "]"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"g", "[", 
       RowBox[{"Evaluate", "[", 
        RowBox[{"FilterRules", "[", 
         RowBox[{
          RowBox[{"{", "opts", "}"}], ",", 
          RowBox[{"Options", "[", "g", "]"}]}], "]"}], "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"h", ":", 
        RowBox[{"OptionValue", "[", "c", "]"}]}], "}"}]}], "}"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"h", "[", 
  RowBox[{"b", "\[Rule]", "bbb"}], "]"}], "\n", 
 RowBox[{"h", "[", 
  RowBox[{
   RowBox[{"b", "\[Rule]", "bbb"}], ",", 
   RowBox[{"c", "\[Rule]", "ccc"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.401489457533019*^9, 3.4014894577132783`*^9}, 
   3.4014895245593987`*^9, {3.4014912328558083`*^9, 3.401491237832965*^9}}],

Cell["\<\
A workaround is to pre-filter the options list for each function that you're \
passing options to:\
\>", "Text",
 CellChangeTimes->{{3.401489490800856*^9, 3.4014895193018384`*^9}, 
   3.4014903850467186`*^9, {3.401490710514718*^9, 3.401490730533504*^9}, {
   3.4014908245086336`*^9, 3.401490825219656*^9}, {3.4014911738609776`*^9, 
   3.40149117407128*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ClearAll", "[", "h", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{"Options", "[", "h", "]"}], "=", 
   RowBox[{"{", 
    RowBox[{"c", "\[Rule]", "c0"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"h", "[", 
   RowBox[{"opts", ":", 
    RowBox[{"OptionsPattern", "[", "]"}]}], "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "Opt", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"gopts", "=", 
      RowBox[{"FilterRules", "[", 
       RowBox[{
        RowBox[{"{", "opts", "}"}], ",", 
        RowBox[{"Options", "[", "g", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"hopts", "=", 
      RowBox[{"FilterRules", "[", 
       RowBox[{
        RowBox[{"{", "opts", "}"}], ",", 
        RowBox[{"Options", "[", "h", "]"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Opt", "[", "x_", "]"}], ":=", 
      RowBox[{"OptionValue", "[", 
       RowBox[{"h", ",", "hopts", ",", "x"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"g", "[", "gopts", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"h", ":", 
         RowBox[{"Opt", "[", "c", "]"}]}], "}"}]}], "}"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"h", "[", 
  RowBox[{"b", "\[Rule]", "bbb"}], "]"}], "\n", 
 RowBox[{"h", "[", 
  RowBox[{
   RowBox[{"b", "\[Rule]", "bbb"}], ",", 
   RowBox[{"c", "\[Rule]", "ccc"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.4014895262117743`*^9, 3.4014895306882114`*^9}, 
   3.4014903483940144`*^9, {3.401490810919093*^9, 3.4014908124312673`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["How to discover what ColorFunctions are built in", "Subsection",
 CellChangeTimes->{{3.401489448159541*^9, 3.4014894549292755`*^9}, {
  3.4014904517025647`*^9, 3.401490467455216*^9}, {3.402202967921875*^9, 
  3.40220298209375*^9}}],

Cell["\<\
It may be obvious to some but it took me a while to find this information \
out.  ColorData[] gives a  of named collections of color schemes\
\>", "Text",
 CellChangeTimes->{{3.402202985421875*^9, 3.402203092203125*^9}}],

Cell[BoxData[
 RowBox[{"ColorData", "[", "]"}]], "Input",
 CellChangeTimes->{{3.402203007*^9, 3.402203009546875*^9}}],

Cell["The Gradients set is what we need", "Text",
 CellChangeTimes->{{3.40220310684375*^9, 3.4022031375625*^9}, {
  3.402203200359375*^9, 3.402203209046875*^9}}],

Cell[BoxData[
 RowBox[{"ColorData", "[", "\"\<Gradients\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.402203075140625*^9, 3.4022030806875*^9}}]
}, Open  ]]
}, Closed]]
},
WindowSize->{1280, 1129},
WindowMargins->{{Automatic, 1}, {Automatic, 0}},
ShowSelection->True,
FrontEndVersion->"7.0 for Linux x86 (32-bit) (February 25, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3487486547-3854386"->{
  Cell[868, 32, 1949, 27, 1295, "Print",
   CellTags->"Info3487486547-3854386"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3487486547-3854386", 43929, 1337}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 158, 2, 108, "Section"],
Cell[CellGroupData[{
Cell[750, 28, 115, 2, 77, "Input"],
Cell[868, 32, 1949, 27, 1295, "Print",
 CellTags->"Info3487486547-3854386"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2854, 64, 100, 1, 56, "Subsection"],
Cell[2957, 67, 195, 4, 73, "Text"],
Cell[3155, 73, 2488, 68, 497, "Input"],
Cell[5646, 143, 61, 0, 44, "Text"],
Cell[5710, 145, 730, 24, 77, "Input"],
Cell[6443, 171, 2244, 62, 437, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8724, 238, 124, 2, 84, "Subsection"],
Cell[8851, 242, 338, 12, 69, "Input"],
Cell[9192, 256, 339, 6, 108, "Text"],
Cell[9534, 264, 1345, 27, 115, "Input"],
Cell[10882, 293, 61, 0, 66, "Text"],
Cell[10946, 295, 476, 15, 115, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11459, 315, 103, 1, 84, "Subsection"],
Cell[11565, 318, 34, 0, 66, "Text"],
Cell[11602, 320, 902, 21, 385, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12541, 346, 32, 0, 84, "Subsection"],
Cell[12576, 348, 155, 3, 66, "Text"],
Cell[12734, 353, 1010, 35, 160, "Input"],
Cell[13747, 390, 121, 3, 66, "Text"],
Cell[13871, 395, 1056, 37, 205, "Input"],
Cell[14930, 434, 205, 7, 67, "Text"],
Cell[15138, 443, 1759, 56, 250, "Input"],
Cell[16900, 501, 209, 5, 67, "Text"],
Cell[17112, 508, 821, 25, 69, "Input"],
Cell[17936, 535, 718, 22, 115, "Input"],
Cell[18657, 559, 175, 2, 66, "Text"],
Cell[18835, 563, 785, 24, 115, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[19657, 592, 111, 1, 84, "Subsection"],
Cell[19771, 595, 108, 4, 67, "Text"],
Cell[19882, 601, 801, 19, 205, "Input"],
Cell[20686, 622, 142, 4, 67, "Text"],
Cell[20831, 628, 671, 18, 250, "Input"],
Cell[21505, 648, 126, 5, 67, "Text"],
Cell[21634, 655, 674, 20, 205, "Input"],
Cell[22311, 677, 201, 5, 67, "Text"],
Cell[22515, 684, 505, 13, 160, "Input"],
Cell[23023, 699, 246, 6, 67, "Text"],
Cell[23272, 707, 719, 17, 205, "Input"],
Cell[23994, 726, 319, 6, 67, "Text"],
Cell[24316, 734, 995, 24, 295, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25348, 763, 57, 0, 84, "Subsection"],
Cell[25408, 765, 187, 7, 67, "Text"],
Cell[25598, 774, 700, 20, 160, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26335, 799, 121, 1, 84, "Subsection"],
Cell[26459, 802, 334, 7, 150, "Text"],
Cell[26796, 811, 579, 15, 205, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27412, 831, 77, 0, 84, "Subsection"],
Cell[27492, 833, 124, 3, 66, "Text"],
Cell[27619, 838, 1145, 34, 160, "Input"],
Cell[28767, 874, 353, 8, 109, "Text"],
Cell[29123, 884, 1777, 50, 520, "Input"],
Cell[30903, 936, 141, 4, 67, "Text"],
Cell[31047, 942, 1922, 55, 475, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[33006, 1002, 48, 0, 84, "Subsection"],
Cell[33057, 1004, 318, 5, 108, "Text"],
Cell[33378, 1011, 487, 9, 109, "Text"],
Cell[33868, 1022, 171, 5, 69, "Input"],
Cell[34042, 1029, 787, 26, 205, "Input"],
Cell[34832, 1057, 291, 6, 67, "Text"],
Cell[35126, 1065, 621, 19, 205, "Input"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[35796, 1090, 180, 6, 162, "Section"],
Cell[CellGroupData[{
Cell[36001, 1100, 161, 2, 76, "Subsection"],
Cell[36165, 1104, 654, 17, 126, "Text"],
Cell[36822, 1123, 1363, 40, 130, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38222, 1168, 197, 2, 76, "Subsection"],
Cell[38422, 1172, 153, 3, 58, "Text"],
Cell[38578, 1177, 639, 18, 130, "Input"],
Cell[39220, 1197, 328, 7, 91, "Text"],
Cell[39551, 1206, 1095, 32, 198, "Input"],
Cell[40649, 1240, 367, 7, 58, "Text"],
Cell[41019, 1249, 1624, 47, 333, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[42680, 1301, 237, 3, 76, "Subsection"],
Cell[42920, 1306, 230, 4, 58, "Text"],
Cell[43153, 1312, 117, 2, 60, "Input"],
Cell[43273, 1316, 161, 2, 58, "Text"],
Cell[43437, 1320, 142, 2, 60, "Input"]
}, Open  ]]
}, Closed]]
}
]
*)

(* End of internal cache information *)
